/*
 * Copyright 2009 OW2 Chameleon
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *���http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.ow2.chameleon.sqlite;

import java.util.Properties;

import javax.sql.DataSource;

import org.osgi.service.jdbc.DataSourceFactory;
import org.sqlite.SQLiteConfig;
import org.sqlite.SQLiteDataSource;

/**
 * SQLite Data Source Factory is a component creating HSQL DataSource.
 * Is is an implementation of the OSGi R4.2 JDBC service.
 * @author <a href="mailto:chameleon-dev@ow2.org">Chameleon Project Team</a>
 */
public class SQLiteDataSourceFactory implements DataSourceFactory {
    /**
     * Configures and returns a SQLite DataSource.
     * @param props the DataSource properties
     * @return  the configured DataSource
     * @see org.osgi.service.jdbc.DataSourceFactory#
     *  createDataSource(java.util.Properties)
     */
    public DataSource createDataSource(Properties props) {
        String url = (String) props.get(JDBC_URL);
        
        if (url == null || url.trim().equals("")) {
            throw new IllegalArgumentException("url was null or blank");
        }
       
        SQLiteConfig config = new SQLiteConfig(props);
        
        SQLiteDataSource dataSource = new SQLiteDataSource(config);
        
        //Set the URL
        dataSource.setUrl(url);
        
        return dataSource;
    }

}
